# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetInstallationTemplatesResult',
    'AwaitableGetInstallationTemplatesResult',
    'get_installation_templates',
    'get_installation_templates_output',
]

@pulumi.output_type
class GetInstallationTemplatesResult:
    """
    A collection of values returned by getInstallationTemplates.
    """
    def __init__(__self__, id=None, results=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if results and not isinstance(results, list):
            raise TypeError("Expected argument 'results' to be a list")
        pulumi.set(__self__, "results", results)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def results(self) -> Sequence[_builtins.str]:
        """
        The list of installation templates IDs available for dedicated servers.
        """
        return pulumi.get(self, "results")


class AwaitableGetInstallationTemplatesResult(GetInstallationTemplatesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstallationTemplatesResult(
            id=self.id,
            results=self.results)


def get_installation_templates(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstallationTemplatesResult:
    """
    Use this data source to get the list of installation templates available for dedicated servers.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    templates = ovh.get_installation_templates()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getInstallationTemplates:getInstallationTemplates', __args__, opts=opts, typ=GetInstallationTemplatesResult).value

    return AwaitableGetInstallationTemplatesResult(
        id=pulumi.get(__ret__, 'id'),
        results=pulumi.get(__ret__, 'results'))
def get_installation_templates_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstallationTemplatesResult]:
    """
    Use this data source to get the list of installation templates available for dedicated servers.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    templates = ovh.get_installation_templates()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getInstallationTemplates:getInstallationTemplates', __args__, opts=opts, typ=GetInstallationTemplatesResult)
    return __ret__.apply(lambda __response__: GetInstallationTemplatesResult(
        id=pulumi.get(__response__, 'id'),
        results=pulumi.get(__response__, 'results')))
