# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('ovh')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def access_token(self) -> Optional[str]:
        """
        The OVH API Access Token
        """
        return __config__.get('accessToken')

    @_builtins.property
    def api_rate_limit(self) -> Optional[int]:
        """
        Specify the API request rate limit, X operations by seconds (default: unlimited)
        """
        return __config__.get_int('apiRateLimit')

    @_builtins.property
    def application_key(self) -> Optional[str]:
        """
        The OVH API Application Key
        """
        return __config__.get('applicationKey')

    @_builtins.property
    def application_secret(self) -> Optional[str]:
        """
        The OVH API Application Secret
        """
        return __config__.get('applicationSecret')

    @_builtins.property
    def client_id(self) -> Optional[str]:
        """
        OAuth 2.0 application's ID
        """
        return __config__.get('clientId')

    @_builtins.property
    def client_secret(self) -> Optional[str]:
        """
        OAuth 2.0 application's secret
        """
        return __config__.get('clientSecret')

    @_builtins.property
    def consumer_key(self) -> Optional[str]:
        """
        The OVH API Consumer Key
        """
        return __config__.get('consumerKey')

    @_builtins.property
    def endpoint(self) -> Optional[str]:
        """
        The OVH API endpoint to target (ex: "ovh-eu")
        """
        return __config__.get('endpoint')

    @_builtins.property
    def user_agent_extra(self) -> Optional[str]:
        """
        Extra information to append to the user-agent
        """
        return __config__.get('userAgentExtra')

